@@ -27,7 +27,9 @@
 mod de;
 mod error;
 mod ser;
+mod transformer;
 
 pub use de::{from_bytes, Deserializer};
 pub use error::{Error, Result};
 pub use ser::{to_bytes, Serializer};
+pub use transformer::Transformer;
